##  Additional Resources
In addition to the methods discussed in this guide, there are several other tools available that you can use to generate your SBOM files. These tools offer different features and capabilities, and you may find some of them better suited to your specific needs.
  * [CDXGEN![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2FCycloneDX%2Fcdxgen "https://github.com/CycloneDX/cdxgen")
  * [Trivy![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Faquasecurity.github.io%2Ftrivy%2Fv0.51%2Fdocs%2Fsupply-chain%2Fsbom%2F "https://aquasecurity.github.io/trivy/v0.51/docs/supply-chain/sbom/")
  * [Syft![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2Fanchore%2Fsyft "https://github.com/anchore/syft")
  * [OSS Review Toolkit![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2Foss-review-toolkit%2Fort "https://github.com/oss-review-toolkit/ort")
